@@ -2,7 +2,10 @@
 pub mod object {
     ///
     pub mod header {
-        //! loose object header encoding and decoding
+        //! loose object header encoding and decoding.
+        //!
+        //! Note that these are still relevant for packs as they are part of the computed hash of any git object, packed or not.
+        //! It just so happened that loose objects where the first ones used for implementing an object database.
         use byteorder::WriteBytesExt;
         use git_object as object;
 
@@ -19,7 +22,7 @@ pub mod object {
             #[error("{0}")]
             InvalidHeader(&'static str),
             #[error(transparent)]
-            ObjectHeader(#[from] object::Error),
+            ObjectHeader(#[from] object::kind::Error),
         }
 
         /// Decode a loose object header, being `<kind> <size>\0`, returns ([`Kind`][object::Kind], `size`, `consumed bytes`).
